Skip to Content.
Sympa Menu

notify-dpml - svn commit: r2534 - development/main

notify-dpml AT lists.ibiblio.org

Subject: DPML Notify

List archive

Chronological Thread  
  • From: mcconnell AT dpml.net
  • To: notify-dpml AT lists.ibiblio.org
  • Subject: svn commit: r2534 - development/main
  • Date: Fri, 13 May 2005 11:42:58 +0000

Author: mcconnell AT dpml.net
Date: Fri May 13 11:42:45 2005
New Revision: 2534

Modified:
development/main/build.sh
Log:
update to include depot build

Modified: development/main/build.sh
==============================================================================
--- development/main/build.sh (original)
+++ development/main/build.sh Fri May 13 11:42:45 2005
@@ -8,12 +8,12 @@
# where the first argument is product group and the second (optional)
argument is the
# build revision identifier. Allowable product group names include:
#
 # all builds transit, util, magic, metro
# transit build transit and util
# magic build magic
+# depot build depot
# metro build metro

-
build()
{
STATUS=99
@@ -48,6 +48,13 @@
cd -
}

+depot()
+{
+ cd depot
+ build clean install
+ cd -
+}
+
metro()
{
cd metro
@@ -72,6 +79,7 @@
echo " transit -- build the transit distribution"
echo " magic -- build the magic distribution"
echo " metro -- build the metro distribution"
+ echo " depot -- build the depot distribution"
echo " all -- builds transit, magic, metro distributions"
echo " [revision] optional build revision identified used when"
echo " building number releases."
@@ -94,6 +102,10 @@
metro
fi

+if [ "$TARGET" == "depot" ] ; then
+ depot
+fi
+
if [ "$TARGET" == "central" ] ; then
central
fi
@@ -106,4 +118,5 @@
transit
magic
metro
+ depot
@@ -8,12 +8,12 @@
# build revision identifier. Allowable product group names include:
#
-# all builds transit, util, magic, metro
+# all builds transit, util, magic, depot, metro
# transit build transit and util
# magic build magic
fi



  • svn commit: r2534 - development/main, mcconnell, 05/13/2005

Archive powered by MHonArc 2.6.24.

Top of Page